@@ -109,6 +109,10 @@ class Database:
         result = self.__read_checkpoint("account_statistics.pickel")
         return result if result is not None else []
 
+    def read_labor_list_from_checkpoint(self) -> List[Dict[str, Any]]:
+        result = self.__read_checkpoint("labor_list.pickel")
+        return result if result is not None else []
+
     @staticmethod
     def task_exists(task_list: List[Task], task_id) -> bool:
         task = more_itertools.first_true(task_list, pred=lambda e: e["task_id"] == task_id)
@@ -329,20 +333,36 @@ class Database:
         self.annofab_service.wrapper.download_annotation_archive(self.project_id, annotations_zip_file, v2=True)
         # task historiesは未完成なので、使わない
 
+    @staticmethod
+    def _to_datetime_with_tz(str_date: str) -> datetime.datetime:
+        dt = dateutil.parser.parse(str_date)
+        dt = dt.replace(tzinfo=dateutil.tz.tzlocal())
+        return dt
+
     def read_tasks_from_json(
-        self, task_query_param: Optional[Dict[str, Any]] = None, ignored_task_id_list: Optional[List[str]] = None,
+        self,
+        task_query_param: Optional[Dict[str, Any]] = None,
+        ignored_task_id_list: Optional[List[str]] = None,
+        start_date: Optional[str] = None,
+        end_date: Optional[str] = None,
     ) -> List[Task]:
         """
-        tass.jsonからqueryに合致するタスクを調べる
+        task.jsonからqueryに合致するタスクを調べる
+
         Args:
             task_query_param: taskを調べるquery. `phase`と`status`のみ有効
             ignored_task_id_list: 無視するtask_idのList
+            start_date: 指定した日付（'YYYY-MM-DD'）より前に更新されているタスクは集計しないようにする。（不要なタスク履歴を参照しないようにする工夫）
+            end_date: 指定した日付（'YYYY-MM-DD'）以前に更新されたタスクを集計する。
 
         Returns:
+            タスク一覧
 
         """
+        dt_end_date = self._to_datetime_with_tz(end_date) if end_date is not None else None
+        dt_start_date = self._to_datetime_with_tz(start_date) if start_date is not None else None
 
-        def filter_task(arg_task):
+        def filter_task(arg_task: Dict[str, Any]):
             """AND条件で絞り込む"""
 
             flag = True
@@ -353,6 +373,15 @@ class Database:
                 if "status" in task_query_param:
                     flag = flag and arg_task["status"] == task_query_param["status"]
 
+                if "task_id" in task_query_param:
+                    flag = flag and str(task_query_param["task_id"]).lower() in str(arg_task["task_id"]).lower()
+
+            if dt_start_date is not None:
+                flag = flag and dateutil.parser.parse(arg_task["updated_datetime"]) >= dt_start_date
+
+            if dt_end_date is not None:
+                flag = flag and dateutil.parser.parse(arg_task["updated_datetime"]) <= dt_end_date
+
             if ignored_task_id_list is not None:
                 flag = flag and arg_task["task_id"] not in ignored_task_id_list
 
@@ -366,12 +395,44 @@ class Database:
         logger.debug(f"集計対象のタスク数 = {len(filtered_task_list)}")
         return filtered_task_list
 
+    @staticmethod
+    def _filter_task_with_task_history(
+        task_list: List[Task], dict_task_histories: Dict[str, List[TaskHistory]], start_date: str
+    ) -> List[Task]:
+        """
+        タスク履歴を参照して、タスクを絞り込む。
+
+        Args:
+            task_list:
+            dict_task_histories:
+            start_date:
+
+        Returns:
+            タスク一覧
+
+        """
+        dt_start_date = Database._to_datetime_with_tz(start_date)
+
+        def pred(task_id: str):
+            task_histories = dict_task_histories[task_id]
+            if len(task_histories) == 0:
+                return False
+
+            first_started_datetime = task_histories[0]["started_datetime"]
+            if first_started_datetime is None:
+                return False
+            return dateutil.parser.parse(first_started_datetime) >= dt_start_date
+
+        return [task for task in task_list if pred(task["task_id"])]
+
     def update_db(
         self,
         task_query_param: Dict[str, Any],
         ignored_task_ids: Optional[List[str]] = None,
         should_update_annotation_zip: bool = False,
         should_update_task_json: bool = False,
+        start_date: Optional[str] = None,
+        end_date: Optional[str] = None,
     ) -> None:
         """
         Annofabから情報を取得し、DB（pickelファイル）を更新する。
@@ -392,25 +453,61 @@ class Database:
         )
 
         logger.info(f"DB更新: task_query_param = {task_query_param}")
-        tasks = self.read_tasks_from_json(task_query_param)
-
-        if ignored_task_ids is not None:
-            # 無視するtask_idを除外する
-            logger.info(f"除外するtask_ids = {ignored_task_ids}")
-            tasks = [e for e in tasks if e["task_id"] not in ignored_task_ids]
+        tasks = self.read_tasks_from_json(
+            task_query_param, start_date=start_date, end_date=end_date, ignored_task_id_list=ignored_task_ids
+        )
 
         old_tasks = self.read_tasks_from_checkpoint()
         not_updated_task_ids = self.get_not_updated_task_ids(old_tasks, tasks)
-        logger.debug(f"更新されていないtask_id = {not_updated_task_ids}")
         logger.info(f"更新されていないタスク数 = {len(not_updated_task_ids)}")
 
         self.__update_task_histories(tasks, not_updated_task_ids)
+
+        if start_date is not None:
+            # start_dateは教師付開始日でみるため、タスク履歴を参照する必要あり
+            dict_task_histories = self.read_task_histories_from_checkpoint()
+            tasks = self._filter_task_with_task_history(
+                tasks, dict_task_histories=dict_task_histories, start_date=start_date
+            )
+
         self.__write_checkpoint(tasks, "tasks.pickel")
 
         # 統計情報の出力
         account_statistics = self.annofab_service.api.get_account_statistics(self.project_id)[0]
         self.__write_checkpoint(account_statistics, "account_statistics.pickel")
 
+        # 労務管理情報の出力
+        labor_list = self._get_labor_list(self.project_id, start_date=start_date, end_date=end_date)
+        self.__write_checkpoint(labor_list, "labor_list.pickel")
+
+    @staticmethod
+    def _get_worktime_hour(working_time_by_user: Optional[Dict[str, Any]], key: str) -> float:
+        if working_time_by_user is None:
+            return 0
+
+        value = working_time_by_user.get(key)
+        if value is None:
+            return 0
+        else:
+            return value / 3600 / 1000
+
+    def _get_labor_list(
+        self, project_id: str, start_date: Optional[str] = None, end_date: Optional[str] = None
+    ) -> List[Dict[str, Any]]:
+        def to_new_labor(e: Dict[str, Any]) -> Dict[str, Any]:
+            return dict(
+                date=e["date"],
+                account_id=e["account_id"],
+                worktime_plan_hour=self._get_worktime_hour(e["values"]["working_time_by_user"], "plans"),
+                worktime_result_hour=self._get_worktime_hour(e["values"]["working_time_by_user"], "results"),
+            )
+
+        labor_list: List[Dict[str, Any]] = self.annofab_service.api.get_labor_control(
+            {"project_id": project_id, "from": start_date, "to": end_date}
+        )[0]
+
+        return [to_new_labor(e) for e in labor_list if e["account_id"] is not None]
+
     @staticmethod
     def get_not_updated_task_ids(old_tasks, new_tasks) -> Set[str]:
         """
