@@ -549,21 +549,21 @@ class LineGraph:
             dict(
                 x="cumulative_task_count",
                 y="cumulative_number_of_rejections",
-                title="タスク数と差押し戻し回数の累積グラフ",
+                title="タスク数と差し戻し回数の累積グラフ",
                 x_axis_label="タスク数",
                 y_axis_label="差し戻し回数",
             ),
             dict(
                 x="cumulative_task_count",
                 y="cumulative_number_of_rejections_by_inspection",
-                title="タスク数と差押し戻し回数(検査フェーズ)の累積グラフ",
+                title="タスク数と差し戻し回数(検査フェーズ)の累積グラフ",
                 x_axis_label="タスク数",
                 y_axis_label="差し戻し回数(検査フェーズ)",
             ),
             dict(
                 x="cumulative_task_count",
                 y="cumulative_number_of_rejections_by_acceptance",
-                title="タスク数と差押し戻し回数(受入フェーズ)の累積グラフ",
+                title="タスク数と差し戻し回数(受入フェーズ)の累積グラフ",
                 x_axis_label="タスク数",
                 y_axis_label="差し戻し回数(受入フェーズ)",
             ),
@@ -707,7 +707,7 @@ class LineGraph:
             dict(
                 x="cumulative_input_data_count",
                 y="cumulative_first_inspection_worktime_hour",
-                title="アノテーション数と1回目検査時間の累積グラフ",
+                title="入力データ数と1回目検査時間の累積グラフ",
                 x_axis_label="入力データ数",
                 y_axis_label="1回目の検査時間[hour]",
             ),
